# various Transformers as feature extractors for ECG tasks

1. Swin Transformer (ref. 1)
2. HaloNet
3. to add ....


## References:
1. Liu, Z., Lin, Y., Cao, Y., Hu, H., Wei, Y., Zhang, Z., ... & Guo, B. (2021). Swin Transformer: Hierarchical Vision Transformer using Shifted Windows. arXiv preprint arXiv:2103.14030.
2. Vaswani, A., Ramachandran, P., Srinivas, A., Parmar, N., Hechtman, B., & Shlens, J. (2021). Scaling Local Self-Attention For Parameter Efficient Visual Backbones. arXiv preprint arXiv:2103.12731.
3. to add ....
